"""
Author: Michel Peltriaux
Organization: Struktur- und Genehmigungsdirektion Nord, Rhineland-Palatinate, Germany
Contact: michel.peltriaux@sgdnord.rlp.de
Created on: 16.11.20

"""

from functools import wraps

from django.contrib import messages
from django.shortcuts import redirect
from django.urls import reverse
from django.utils.translation import gettext_lazy as _


def staff_required(function):
    """
    A decorator for functions which shall only be usable for staff members of the system
    """
    @wraps(function)
    def wrap(request, *args, **kwargs):
        user = request.user
        if user.is_staff:
            return function(request, *args, **kwargs)
        else:
            messages.info(request, _("You need to be staff to perform this action!"))
            return redirect(request.META.get("HTTP_REFERER", reverse("home")))
    return wrap


def superuser_required(function):
    """
    A decorator for functions which shall only be usable for superusers of the system
    """
    @wraps(function)
    def wrap(request, *args, **kwargs):
        user = request.user
        if user.is_superuser:
            return function(request, *args, **kwargs)
        else:
            messages.info(request, _("You need to be administrator to perform this action!"))
            return redirect(request.META.get("HTTP_REFERER", reverse("home")))
    return wrap